@@ -1,4 +1,4 @@
-//$Id: examplewindow.cc 608 2006-05-10 12:43:31Z murrayc $ -*- c++ -*-
+//$Id: examplewindow.cc,v 1.6 2005/03/04 20:29:02 murrayc Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -78,8 +78,9 @@ ExampleWindow::ExampleWindow()
   add_accel_group(m_refUIManager->get_accel_group());
 
   //Layout the actions in a menubar and toolbar:
-  
-  Glib::ustring ui_info = 
+  try
+  {
+    Glib::ustring ui_info = 
         "<ui>"
         "  <menubar name='MenuBar'>"
         "    <menu action='FileMenu'>"
@@ -109,24 +110,13 @@ ExampleWindow::ExampleWindow()
         "    <toolitem action='FileQuit'/>"
         "  </toolbar>"
         "</ui>";
-
-  #ifdef GLIBMM_EXCEPTIONS_ENABLED
-  try
-  {      
+        
     m_refUIManager->add_ui_from_string(ui_info);
   }
   catch(const Glib::Error& ex)
   {
     std::cerr << "building menus failed: " <<  ex.what();
   }
-  #else
-  std::auto_ptr<Glib::Error> ex;
-  m_refUIManager->add_ui_from_string(ui_info, ex);
-  if(ex.get())
-  { 
-    std::cerr << "building menus failed: " <<  ex->what();
-  }
-  #endif //GLIBMM_EXCEPTIONS_ENABLED
 
  
   //Get the menubar and toolbar widgets, and add them to a container widget:
